<?php
/**
 * Aqeeq Agency Theme Customizer
 *
 * @package Aqeeq Agency
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function aqeeq_agency_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'aqeeq_agency_custom_controls' );

function aqeeq_agency_customize_register( $wp_customize ) {

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; 
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'aqeeq_agency_Customize_partial_blogname',
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'aqeeq_agency_Customize_partial_blogdescription',
	));

	// add home page setting pannel
	$wp_customize->add_panel( 'aqeeq_agency_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'VW Settings', 'aqeeq-agency' ),
		'priority' => 10,
	));

	// Layout
	$wp_customize->add_section( 'aqeeq_agency_left_right', array(
    	'title' => esc_html__('General Settings', 'aqeeq-agency'),
		'panel' => 'aqeeq_agency_panel_id'
	) );

	$wp_customize->add_setting('aqeeq_agency_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control(new Aqeeq_Agency_Image_Radio_Control($wp_customize, 'aqeeq_agency_width_option', array(
        'type' => 'select',
        'label' => esc_html__('Width Layouts','aqeeq-agency'),
        'description' => esc_html__('Here you can change the width layout of Website.','aqeeq-agency'),
        'section' => 'aqeeq_agency_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('aqeeq_agency_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_theme_options',array(
        'type' => 'select',
        'label' => esc_html__('Post Sidebar Layout','aqeeq-agency'),
        'description' => esc_html__('Here you can change the sidebar layout for posts. ','aqeeq-agency'),
        'section' => 'aqeeq_agency_left_right',
        'choices' => array(
            'Left Sidebar' => esc_html__('Left Sidebar','aqeeq-agency'),
            'Right Sidebar' => esc_html__('Right Sidebar','aqeeq-agency'),
            'One Column' => esc_html__('One Column','aqeeq-agency'),
            'Grid Layout' => esc_html__('Grid Layout','aqeeq-agency')
        ),
	) );

	$wp_customize->add_setting('aqeeq_agency_page_layout',array(
        'default' => 'One_Column',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_page_layout',array(
        'type' => 'select',
        'label' => esc_html__('Page Sidebar Layout','aqeeq-agency'),
        'description' => esc_html__('Here you can change the sidebar layout for pages. ','aqeeq-agency'),
        'section' => 'aqeeq_agency_left_right',
        'choices' => array(
            'Left_Sidebar' => esc_html__('Left Sidebar','aqeeq-agency'),
            'Right_Sidebar' => esc_html__('Right Sidebar','aqeeq-agency'),
            'One_Column' => esc_html__('One Column','aqeeq-agency')
        ),
	) );

	// Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'aqeeq_agency_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product #sidebar', 
		'render_callback' => 'aqeeq_agency_customize_partial_aqeeq_agency_woocommerce_shop_page_sidebar', ) );

    // Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'aqeeq_agency_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','aqeeq-agency' ),
		'section' => 'aqeeq_agency_left_right'
    )));

    // Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'aqeeq_agency_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar', 
		'render_callback' => 'aqeeq_agency_customize_partial_aqeeq_agency_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'aqeeq_agency_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','aqeeq-agency' ),
		'section' => 'aqeeq_agency_left_right'
    )));

    // Pre-Loader
	$wp_customize->add_setting( 'aqeeq_agency_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','aqeeq-agency' ),
        'section' => 'aqeeq_agency_left_right'
    )));

	$wp_customize->add_setting('aqeeq_agency_preloader_bg_color', array(
		'default'           => '#ff44b6',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'aqeeq_agency_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'aqeeq-agency'),
		'section'  => 'aqeeq_agency_left_right',
	)));

	$wp_customize->add_setting('aqeeq_agency_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'aqeeq_agency_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'aqeeq-agency'),
		'section'  => 'aqeeq_agency_left_right',
	)));

	//Header
	$wp_customize->add_section( 'aqeeq_agency_header_section' , array(
    	'title' => __( 'Header Section', 'aqeeq-agency' ),
		'panel' => 'aqeeq_agency_panel_id'
	) );

	$wp_customize->add_setting('aqeeq_agency_header_btn_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_header_btn_text',array(
		'label'	=> esc_html__('Add Button Text','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Get Free Quote', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_header_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_header_btn_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('aqeeq_agency_header_btn_link',array(
		'label'	=> esc_html__('Add Button Link','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example-info.com', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_header_section',
		'type'=> 'url'
	));

	//Slider
	$wp_customize->add_section( 'aqeeq_agency_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'aqeeq-agency' ),
		'panel' => 'aqeeq_agency_panel_id'
	) );

	$wp_customize->add_setting( 'aqeeq_agency_slider_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ));  
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','aqeeq-agency' ),
      'section' => 'aqeeq_agency_slidersettings'
    )));

     //Selective Refresh
    $wp_customize->selective_refresh->add_partial('aqeeq_agency_slider_hide_show',array(
		'selector'        => '.slider-btn a',
		'render_callback' => 'aqeeq_agency_customize_partial_aqeeq_agency_slider_hide_show',
	));

	for ( $count = 1; $count <= 4; $count++ ) {
		$wp_customize->add_setting( 'aqeeq_agency_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'aqeeq_agency_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'aqeeq_agency_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'aqeeq-agency' ),
			'description' => __('Slider image size (1400 x 550)','aqeeq-agency'),
			'section'  => 'aqeeq_agency_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	$wp_customize->add_setting( 'aqeeq_agency_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'aqeeq_agency_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','aqeeq-agency'),
		'section' => 'aqeeq_agency_slidersettings',
		'type'  => 'text',
	) );

	// Features Section
	$wp_customize->add_section('aqeeq_agency_features_section',array(
		'title'	=> __('Features Section','aqeeq-agency'),
		'description' => __('Add section title and select the category to display for features post','aqeeq-agency'),
		'panel' => 'aqeeq_agency_panel_id',
	));

	$wp_customize->add_setting( 'aqeeq_agency_features_small_title', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'aqeeq_agency_features_small_title', array(
		'label'    => __( 'Add Section Small Title', 'aqeeq-agency' ),
		'input_attrs' => array(
            'placeholder' => __( 'OUR FEATURES', 'aqeeq-agency' ),
        ),
		'section'  => 'aqeeq_agency_features_section',
		'type'     => 'text'
	) );

	$wp_customize->add_setting( 'aqeeq_agency_features_heading', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'aqeeq_agency_features_heading', array(
		'label'    => __( 'Add Section Heading', 'aqeeq-agency' ),
		'input_attrs' => array(
            'placeholder' => __( 'UNIQUE SOLUTIONS FOR YOUR PROBLEM', 'aqeeq-agency' ),
        ),
		'section'  => 'aqeeq_agency_features_section',
		'type'     => 'text'
	) );

	$wp_customize->add_setting( 'aqeeq_agency_featured_content', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'aqeeq_agency_featured_content', array(
		'label'    => __( 'Add Section Content', 'aqeeq-agency' ),
		'input_attrs' => array(
            'placeholder' => __( 'Lorem Ipsum Dolor Sit Amet', 'aqeeq-agency' ),
        ),
		'section'  => 'aqeeq_agency_features_section',
		'type'     => 'text'
	) );

	$categories = get_categories();
	$cat_post = array();
	$cat_post[]= 'select';
	$i = 0;	
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('aqeeq_agency_features_category',array(
		'default'	=> 'select',
		'sanitize_callback' => 'aqeeq_agency_sanitize_choices',
	));
	$wp_customize->add_control('aqeeq_agency_features_category',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => __('Select Category to display Features Post','aqeeq-agency'),
		'section' => 'aqeeq_agency_features_section',
	));

	//Blog Post
	$wp_customize->add_panel( 'aqeeq_agency_blog_post_parent_panel', array(
		'title' => esc_html__( 'Blog Post Settings', 'aqeeq-agency' ),
		'panel' => 'aqeeq_agency_panel_id',
		'priority' => 20,
	));

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'aqeeq_agency_post_settings', array(
		'title' => esc_html__( 'Post Settings', 'aqeeq-agency' ),
		'panel' => 'aqeeq_agency_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('aqeeq_agency_toggle_postdate', array( 
		'selector' => '.post-main-box h2 a', 
		'render_callback' => 'aqeeq_agency_Customize_partial_aqeeq_agency_toggle_postdate', 
	));

	$wp_customize->add_setting( 'aqeeq_agency_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','aqeeq-agency' ),
        'section' => 'aqeeq_agency_post_settings'
    )));

    $wp_customize->add_setting( 'aqeeq_agency_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_toggle_author',array(
		'label' => esc_html__( 'Author','aqeeq-agency' ),
		'section' => 'aqeeq_agency_post_settings'
    )));

    $wp_customize->add_setting( 'aqeeq_agency_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_toggle_comments',array(
		'label' => esc_html__( 'Comments','aqeeq-agency' ),
		'section' => 'aqeeq_agency_post_settings'
    )));

    $wp_customize->add_setting( 'aqeeq_agency_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_toggle_time',array(
		'label' => esc_html__( 'Time','aqeeq-agency' ),
		'section' => 'aqeeq_agency_post_settings'
    )));

    $wp_customize->add_setting( 'aqeeq_agency_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
	));
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_featured_image_hide_show', array(
		'label' => esc_html__( 'Featured Image','aqeeq-agency' ),
		'section' => 'aqeeq_agency_post_settings'
    )));

    $wp_customize->add_setting( 'aqeeq_agency_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
	));
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_toggle_tags', array(
		'label' => esc_html__( 'Tags','aqeeq-agency' ),
		'section' => 'aqeeq_agency_post_settings'
    )));

    $wp_customize->add_setting( 'aqeeq_agency_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'aqeeq_agency_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'aqeeq_agency_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','aqeeq-agency' ),
		'section'     => 'aqeeq_agency_post_settings',
		'type'        => 'range',
		'settings'    => 'aqeeq_agency_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('aqeeq_agency_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','aqeeq-agency'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','aqeeq-agency'),
		'section'=> 'aqeeq_agency_post_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('aqeeq_agency_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Post Content','aqeeq-agency'),
        'section' => 'aqeeq_agency_post_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','aqeeq-agency'),
            'Excerpt' => esc_html__('Excerpt','aqeeq-agency'),
            'No Content' => esc_html__('No Content','aqeeq-agency')
        ),
	) );

    // Button Settings
	$wp_customize->add_section( 'aqeeq_agency_button_settings', array(
		'title' => esc_html__( 'Button Settings', 'aqeeq-agency' ),
		'panel' => 'aqeeq_agency_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('aqeeq_agency_button_text', array( 
		'selector' => '.post-main-box .more-btn a', 
		'render_callback' => 'aqeeq_agency_Customize_partial_aqeeq_agency_button_text', 
	));

    $wp_customize->add_setting('aqeeq_agency_button_text',array(
		'default'=> esc_html__('Read More','aqeeq-agency'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_button_text',array(
		'label'	=> esc_html__('Add Button Text','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_button_settings',
		'type'=> 'text'
	));

	// Related Post Settings
	$wp_customize->add_section( 'aqeeq_agency_related_posts_settings', array(
		'title' => esc_html__( 'Related Posts Settings', 'aqeeq-agency' ),
		'panel' => 'aqeeq_agency_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('aqeeq_agency_related_post_title', array( 
		'selector' => '.related-post h3', 
		'render_callback' => 'aqeeq_agency_Customize_partial_aqeeq_agency_related_post_title', 
	));

    $wp_customize->add_setting( 'aqeeq_agency_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_related_post',array(
		'label' => esc_html__( 'Related Post','aqeeq-agency' ),
		'section' => 'aqeeq_agency_related_posts_settings'
    )));

    $wp_customize->add_setting('aqeeq_agency_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_related_post_title',array(
		'label'	=> esc_html__('Add Related Post Title','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Related Post', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('aqeeq_agency_related_posts_count',array(
		'default'=> 3,
		'sanitize_callback'	=> 'aqeeq_agency_sanitize_number_absint'
	));
	$wp_customize->add_control('aqeeq_agency_related_posts_count',array(
		'label'	=> esc_html__('Add Related Post Count','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '3', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_related_posts_settings',
		'type'=> 'number'
	));

	//Responsive Media Settings
	$wp_customize->add_section('aqeeq_agency_responsive_media',array(
		'title'	=> esc_html__('Responsive Media','aqeeq-agency'),
		'panel' => 'aqeeq_agency_panel_id',
	));

    $wp_customize->add_setting( 'aqeeq_agency_resp_slider_hide_show',array(
      	'default' => 0,
     	'transport' => 'refresh',
      	'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ));  
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_resp_slider_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Slider','aqeeq-agency' ),
      	'section' => 'aqeeq_agency_responsive_media'
    )));

    $wp_customize->add_setting( 'aqeeq_agency_sidebar_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ));  
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_sidebar_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Sidebar','aqeeq-agency' ),
      	'section' => 'aqeeq_agency_responsive_media'
    )));

    $wp_customize->add_setting( 'aqeeq_agency_resp_scroll_top_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ));  
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_resp_scroll_top_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','aqeeq-agency' ),
      	'section' => 'aqeeq_agency_responsive_media'
    )));

	//Footer Text
	$wp_customize->add_section('aqeeq_agency_footer',array(
		'title'	=> esc_html__('Footer Settings','aqeeq-agency'),
		'panel' => 'aqeeq_agency_panel_id',
	));	

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('aqeeq_agency_footer_text', array( 
		'selector' => '.copyright p', 
		'render_callback' => 'aqeeq_agency_Customize_partial_aqeeq_agency_footer_text', 
	));
	
	$wp_customize->add_setting('aqeeq_agency_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('aqeeq_agency_footer_text',array(
		'label'	=> esc_html__('Copyright Text','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Copyright 2021, .....', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_copyright_alingment',array(
        'default' => 'center',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control(new Aqeeq_Agency_Image_Radio_Control($wp_customize, 'aqeeq_agency_copyright_alingment', array(
        'type' => 'select',
        'label' => esc_html__('Copyright Alignment','aqeeq-agency'),
        'section' => 'aqeeq_agency_footer',
        'settings' => 'aqeeq_agency_copyright_alingment',
        'choices' => array(
            'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
            'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
            'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
    ))));

    $wp_customize->add_setting( 'aqeeq_agency_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ));  
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll to Top','aqeeq-agency' ),
      	'section' => 'aqeeq_agency_footer'
    )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial('aqeeq_agency_scroll_to_top_icon', array( 
		'selector' => '.scrollup i', 
		'render_callback' => 'aqeeq_agency_Customize_partial_aqeeq_agency_scroll_to_top_icon', 
	));

    $wp_customize->add_setting('aqeeq_agency_scroll_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control(new Aqeeq_Agency_Image_Radio_Control($wp_customize, 'aqeeq_agency_scroll_top_alignment', array(
        'type' => 'select',
        'label' => esc_html__('Scroll To Top','aqeeq-agency'),
        'section' => 'aqeeq_agency_footer',
        'settings' => 'aqeeq_agency_scroll_top_alignment',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/layout2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/layout3.png'
    ))));
}

add_action( 'customize_register', 'aqeeq_agency_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Aqeeq_Agency_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Aqeeq_Agency_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new Aqeeq_Agency_Customize_Section_Pro( $manager,'aqeeq_agency_go_pro', array(
			'priority'   => 1,
			'title'    => esc_html__( 'AQEEQ AGENCY PRO', 'aqeeq-agency' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'aqeeq-agency' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/aqeeq-agency-wordpress-theme/'),
		) )	);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'aqeeq-agency-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'aqeeq-agency-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Aqeeq_Agency_Customize::get_instance();